@@ -53,10 +53,7 @@ std::wstring string_to_wide_string(const std::string& string) {
  * @param io_context
  * @param logger
  * @param first_start_expected
- * @param check_interval
  * @param serv
- * @param cmd_name
- * @param cmd_line
  * @param args
  * @param cnf
  * @param handler
@@ -65,10 +62,7 @@ check_counter::check_counter(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const rapidjson::Value& args,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
@@ -76,10 +70,7 @@ check_counter::check_counter(
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
             stat),
@@ -97,24 +88,8 @@ check_counter::check_counter(
       _calc_output_format();
       _warning_status = arg.get_string("warning-status", "");
       _critical_status = arg.get_string("critical-status", "");
-
-      // check if the field warning_count and critical_count are int or string
-
-      _warning_threshold.extract_range(
-          arg.get_string_or_int_as_string("warning-count", "0"));
-      _critical_threshold.extract_range(
-          arg.get_string_or_int_as_string("critical-count", "0"));
-
-      // the number of warning/critical will always be positive or zero
-      // if the low threshold is not set, we take the default value
-      _warning_threshold.set_default_low(0);
-      _critical_threshold.set_default_low(0);
-
-      if (!_warning_threshold.is_valid() || !_critical_threshold.is_valid()) {
-        throw std::runtime_error(
-            "check_counter, invalid warning-count or critical-count range");
-      }
-
+      _warning_threshold_count = arg.get_int("warning-count", 1);
+      _critical_threshold_count = arg.get_int("critical-count", 1);
       _verbose = arg.get_bool("verbose", false);
       _use_english = arg.get_bool("use_english", false);
     }
@@ -412,22 +387,17 @@ e_status check_counter::compute(
     common::perfdata c_warn_pref;
     c_warn_pref.name("warning-count");
     c_warn_pref.value(_warning_list.size());
-    _warning_threshold.set_pref_details_w(c_warn_pref);
-
     perfs->emplace_back(std::move(c_warn_pref));
     common::perfdata c_crit_pref;
     c_crit_pref.name("critical-count");
     c_crit_pref.value(_critical_list.size());
-    _critical_threshold.set_pref_details_c(c_crit_pref);
-
     perfs->emplace_back(std::move(c_crit_pref));
   }
 
   // check the status
-  if (is_critical && _critical_threshold.is_triggered(_critical_list.size())) {
+  if (is_critical && _critical_list.size() >= _critical_threshold_count) {
     ret = e_status::critical;
-  } else if (is_warning &&
-             _warning_threshold.is_triggered(_warning_list.size())) {
+  } else if (is_warning && _warning_list.size() >= _warning_threshold_count) {
     ret = e_status::warning;
   } else {
     ret = e_status::ok;
@@ -479,10 +449,11 @@ void check_counter::start_check(const duration& timeout) {
       });
     } else {
       // if we need two samples, we need to wait for the second one
-      time_point end_measure = std::chrono::system_clock::now() + timeout;
-      end_measure -= std::chrono::seconds(1);
+      duration wait_duration =
+          std::min(get_raw_start_expected().get_step() / 2,
+                   timeout - std::chrono::milliseconds(500));
 
-      _measure_timer.expires_at(end_measure);
+      _measure_timer.expires_after(wait_duration);
       _measure_timer.async_wait(
           [me = shared_from_this(),
            start_check_index = _get_running_check_index()](
@@ -558,10 +529,12 @@ JSON arguments
     "critical-status"    : string,                 # Filter expression that
                                                      marks an item CRITICAL.
                                                      Ex: "value > 90".
-    "warning-count"      : string (default 0),     # Threshold of items number with warning status
-                                                     to trigger WARNING.
-    "critical-count"     : string (default 0),     # Threshold of items number with critical status
-                                                     to trigger CRITICAL.
+    "warning-count"      : integer (default 1),    # Minimum WARNING items
+                                                     before overall status is
+                                                     WARNING.
+    "critical-count"     : integer (default 1),    # Minimum CRITICAL items
+                                                     before overall status is
+                                                     CRITICAL.
     "verbose"            : bool (default false),   # add verbose output in the end.
     "use_english"        : bool (default false)    # Force English counter
                                                      names.
@@ -588,7 +561,7 @@ Example
   "detail_syntax"   : "{label}={value}",
   "warning-status"  : "value > 75",
   "critical-status" : "value > 90",
-  "warning-count"   : "10",
+  "warning-count"   : 10,
   "verbose"         : false
 }")";
 }
