@@ -73,10 +73,7 @@ static DateInfo date_to_info(DATE date) {
  * @param io_context
  * @param logger
  * @param first_start_expected
- * @param check_interval
  * @param serv
- * @param cmd_name
- * @param cmd_line
  * @param args
  * @param cnf
  * @param handler
@@ -84,10 +81,7 @@ static DateInfo date_to_info(DATE date) {
 check_sched::check_sched(const std::shared_ptr<asio::io_context>& io_context,
                          const std::shared_ptr<spdlog::logger>& logger,
                          time_point first_start_expected,
-                         duration check_interval,
-                         const std::string& serv,
-                         const std::string& cmd_name,
-                         const std::string& cmd_line,
+                         const Service& serv,
                          const rapidjson::Value& args,
                          const engine_to_agent_request_ptr& cnf,
                          check::completion_handler&& handler,
@@ -95,10 +89,7 @@ check_sched::check_sched(const std::shared_ptr<asio::io_context>& io_context,
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
             stat) {
@@ -117,24 +108,9 @@ check_sched::check_sched(const std::shared_ptr<asio::io_context>& io_context,
       _warning_status = arg.get_string("warning-status", "exit_code != 0");
       _critical_status = arg.get_string("critical-status", "exit_code < 0");
 
-      // check if the field warning_count and critical_count are int or string
-      _warning_threshold.extract_range(
-          arg.get_string_or_int_as_string("warning-count", "0"));
-      _critical_threshold.extract_range(
-          arg.get_string_or_int_as_string("critical-count", "0"));
-
-      // the number of warning/critical will always be positive or zero
-      // if the low threshold is not set, we take the default value
-      _warning_threshold.set_default_low(0);
-      _critical_threshold.set_default_low(0);
-
-      if (!_warning_threshold.is_valid() || !_critical_threshold.is_valid()) {
-        SPDLOG_LOGGER_ERROR(
-            _logger,
-            "check_sched, invalid warning-count or critical-count range");
-        throw std::runtime_error(
-            "check_sched, invalid warning-count or critical-count range");
-      }
+      // conditions to trigger warning and critical
+      _warning_threshold_count = arg.get_int("warning-count", 1);
+      _critical_threshold_count = arg.get_int("critical-count", 1);
 
       _verbose = arg.get_bool("verbose", false);
     }
@@ -216,9 +192,11 @@ e_status check_sched::compute(
   }
 
   // check the status
-  if (_critical_threshold.is_triggered(_critical_list.size())) {
+  if (_critical_list.size() != 0 &&
+      _critical_list.size() >= _critical_threshold_count) {
     ret = e_status::critical;
-  } else if (_warning_threshold.is_triggered(_warning_list.size())) {
+  } else if (_warning_list.size() != 0 &&
+             _warning_list.size() >= _warning_threshold_count) {
     ret = e_status::warning;
   } else {
     ret = e_status::ok;
@@ -233,12 +211,10 @@ e_status check_sched::compute(
 
     perf.name("warning_count");
     perf.value(_warning_list.size());
-    _warning_threshold.set_pref_details_w(perf);
     perfs->emplace_back(std::move(perf));
 
     perf.name("critical_count");
     perf.value(_critical_list.size());
-    _critical_threshold.set_pref_details_c(perf);
     perfs->emplace_back(std::move(perf));
   }
   if (_verbose) {
@@ -928,10 +904,12 @@ JSON arguments
     "critical-status"    : string,                 # Filter expression that
                                                      marks a task CRITICAL.
                                                      Default: "exit_code < 0"
-    "warning-count"      : string (default 0),     # Threshold of items number with warning status
-                                                     to trigger WARNING.
-    "critical-count"     : string (default 0),     # Threshold of items number with critical status
-                                                     to trigger CRITICAL.
+    "warning-count"      : integer (default 1),    # Minimum WARNING tasks
+                                                     before overall status is
+                                                     WARNING.
+    "critical-count"     : integer (default 1),    # Minimum CRITICAL tasks
+                                                     before overall status is
+                                                     CRITICAL.
     "verbose"            : bool (default false),    # Add verbose output including
                                                      detailed task information.
   }
@@ -978,8 +956,8 @@ Example
   "filter-tasks"       : "enabled == 1",
   "warning-status"     : "exit_code != 0",
   "critical-status"    : "exit_code < 0 || missed_runs > 2",
-  "warning-count"      : "1",
-  "critical-count"     : "1",
+  "warning-count"      : 1,
+  "critical-count"     : 1,
   "verbose"            : false
 })";
 }
