@@ -52,7 +52,8 @@ std::list<fs_stat> os_fs_stats(filter& filter,
 
 using namespace com::centreon::agent;
 
-#define SERVICE_NAME "CentreonMonitoringAgent"
+// Default Windows service name (can now be overridden through --service-name)
+static std::string g_service_name = "CentreonMonitoringAgent";
 
 std::shared_ptr<asio::io_context> g_io_context =
     std::make_shared<asio::io_context>();
@@ -127,6 +128,9 @@ void show_help() {
   std::cout << "  --standalone: run the agent in standalone mode not from "
                "service manager (mandatory for start it from command line)"
             << std::endl;
+  std::cout << "  --service-name <name>: override Windows Service name (also "
+               "registry path SOFTWARE\\Centreon\\<name>)"
+            << std::endl;
   std::cout << "  --help: show this help" << std::endl;
   std::cout << std::endl << "native checks options:" << std::endl;
   check_cpu::help(std::cout);
@@ -150,7 +154,7 @@ void show_help() {
  * @return int exit status returned to command line (0 success)
  */
 int _main(bool service_start) {
-  std::string registry_path = "SOFTWARE\\Centreon\\" SERVICE_NAME;
+  std::string registry_path = "SOFTWARE\\Centreon\\" + g_service_name;
 
   try {
     config::load(registry_path);
@@ -164,16 +168,11 @@ int _main(bool service_start) {
   check_drive_size_detail::drive_size_thread::os_fs_stats =
       check_drive_size_detail::os_fs_stats;
 
-  if (service_start)
-    SPDLOG_INFO("centreon-monitoring-agent service start");
-  else
-    SPDLOG_INFO("centreon-monitoring-agent start");
-
   const std::string logger_name = "centreon-monitoring-agent";
 
   auto create_event_logger = []() {
     auto sink =
-        std::make_shared<spdlog::sinks::win_eventlog_sink_mt>(SERVICE_NAME);
+        std::make_shared<spdlog::sinks::win_eventlog_sink_mt>(g_service_name);
     g_logger = std::make_shared<spdlog::logger>("", sink);
   };
 
@@ -216,7 +215,18 @@ int _main(bool service_start) {
 
   set_grpc_logger();
 
-  SPDLOG_LOGGER_INFO(g_logger, "centreon-monitoring-agent start");
+  if (service_start)
+    SPDLOG_LOGGER_INFO(
+        g_logger,
+        "centreon-monitoring-agent service started with registry configuration "
+        "{} ",
+        g_service_name);
+  else
+    SPDLOG_LOGGER_INFO(
+        g_logger,
+        "centreon-monitoring-agent start with registry configuration {} ",
+        g_service_name);
+
   std::shared_ptr<com::centreon::common::grpc::grpc_config> grpc_conf;
 
   try {
@@ -301,21 +311,37 @@ void WINAPI SvcMain(DWORD, LPTSTR*);
  * @return int program status
  */
 int main(int argc, char* argv[]) {
-  if (argc > 1 && !lstrcmpi(argv[1], "--standalone")) {
+  bool standalone = false;
+  // Simple manual parsing (arguments count is low). We consider pairs for
+  // --service-name
+  for (int i = 1; i < argc; ++i) {
+    if (!lstrcmpi(argv[i], "--help")) {
+      show_help();
+      return 0;
+    } else if (!lstrcmpi(argv[i], "--standalone")) {
+      standalone = true;
+    } else if (!lstrcmpi(argv[i], "--service-name")) {
+      if (i + 1 < argc) {
+        g_service_name = argv[++i];
+      } else {
+        std::cerr << "--service-name requires a value" << std::endl;
+        return 1;
+      }
+    }
+  }
+
+  if (standalone) {
     return _main(false);
   }
 
-  if (argc > 1 && !lstrcmpi(argv[1], "--help")) {
-    show_help();
-    return 0;
-  }
-
   SPDLOG_INFO(
-      "centagent.exe will start in service mode, if you launch it from command "
-      "line, use --standalone flag");
+      "centagent.exe will start in service mode with service name '{}', if you "
+      "launch it from command line, use --standalone flag",
+      g_service_name);
 
-  const SERVICE_TABLE_ENTRY DispatchTable[] = {
-      {(LPSTR)SERVICE_NAME, (LPSERVICE_MAIN_FUNCTION)SvcMain}, {NULL, NULL}};
+  SERVICE_TABLE_ENTRY DispatchTable[] = {
+      {(LPSTR)g_service_name.c_str(), (LPSERVICE_MAIN_FUNCTION)SvcMain},
+      {NULL, NULL}};
 
   // This call returns when the service has stopped.
   // The process should simply terminate when the call returns.
@@ -391,7 +417,8 @@ void WINAPI SvcCtrlHandler(DWORD dwCtrl) {
  *
  */
 void WINAPI SvcMain(DWORD, LPTSTR*) {
-  gSvcStatusHandle = RegisterServiceCtrlHandler(SERVICE_NAME, SvcCtrlHandler);
+  gSvcStatusHandle =
+      RegisterServiceCtrlHandler(g_service_name.c_str(), SvcCtrlHandler);
 
   if (!gSvcStatusHandle) {
     SPDLOG_LOGGER_CRITICAL(g_logger, "fail to RegisterServiceCtrlHandler");
