@@ -20,7 +20,6 @@
 #include "com/centreon/common/rapidjson_helper.hh"
 
 using namespace com::centreon::agent;
-using namespace com::centreon;
 using namespace com::centreon::agent::native_check_detail;
 
 /**
@@ -37,17 +36,16 @@ using namespace com::centreon::agent::native_check_detail;
 template <unsigned nb_metric>
 measure_to_status<nb_metric>::measure_to_status(e_status status,
                                                 unsigned data_index,
-                                                common::threshold threshold,
+                                                double threshold,
                                                 unsigned total_data_index,
-                                                bool percent)
+                                                bool percent,
+                                                bool free_threshold)
     : _status(status),
       _data_index(data_index),
-      _threshold(std::move(threshold)),
+      _threshold(threshold),
       _total_data_index(total_data_index),
-      _percent(percent) {
-  if (percent)
-    _threshold.unit_multiplier(1.0 / 100.0);
-}
+      _percent(percent),
+      _free_threshold(free_threshold) {}
 
 template <unsigned nb_metric>
 void measure_to_status<nb_metric>::compute_status(
@@ -59,9 +57,14 @@ void measure_to_status<nb_metric>::compute_status(
   double value =
       _percent ? to_test.get_proportional_value(_data_index, _total_data_index)
                : to_test.get_metric(_data_index);
-
-  if (_threshold.is_triggered(value)) {
-    *status = _status;
+  if (_free_threshold) {
+    if (value < _threshold) {
+      *status = _status;
+    }
+  } else {
+    if (value > _threshold) {
+      *status = _status;
+    }
   }
 }
 
@@ -71,11 +74,7 @@ void measure_to_status<nb_metric>::compute_status(
  * @param io_context
  * @param logger
  * @param first_start_expected start expected
- * @param check_interval check interval between two checks (not only this but
- * also others)
  * @param serv service
- * @param cmd_name
- * @param cmd_line
  * @param args native plugin arguments
  * @param cnf engine configuration received object
  * @param handler called at measure completion
@@ -85,10 +84,7 @@ native_check_base<nb_metric>::native_check_base(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const rapidjson::Value& args,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
@@ -96,10 +92,7 @@ native_check_base<nb_metric>::native_check_base(
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
             stat) {}
@@ -190,15 +183,19 @@ e_status native_check_base<nb_metric>::compute(
     auto mem_to_status_search = _measure_to_status.find(std::make_tuple(
         metric.data_index, metric.total_data_index, e_status::warning));
     if (mem_to_status_search != _measure_to_status.end()) {
-      mem_to_status_search->second->get_threshold().set_pref_details_w(
-          to_add, metric.percent ? 100.0 : 1.0);
+      to_add.warning_low(0);
+      to_add.warning(metric.percent
+                         ? 100 * mem_to_status_search->second->get_threshold()
+                         : mem_to_status_search->second->get_threshold());
     }
     // critical
     mem_to_status_search = _measure_to_status.find(std::make_tuple(
         metric.data_index, metric.total_data_index, e_status::critical));
     if (mem_to_status_search != _measure_to_status.end()) {
-      mem_to_status_search->second->get_threshold().set_pref_details_c(
-          to_add, metric.percent ? 100.0 : 1.0);
+      to_add.critical_low(0);
+      to_add.critical(metric.percent
+                          ? 100 * mem_to_status_search->second->get_threshold()
+                          : mem_to_status_search->second->get_threshold());
     }
   }
   return status;
