@@ -20,7 +20,6 @@
 #include "com/centreon/common/rapidjson_helper.hh"
 
 using namespace com::centreon::agent;
-using namespace com::centreon;
 using namespace com::centreon::agent::check_cpu_detail;
 
 /**
@@ -180,7 +179,7 @@ void cpu_to_status<nb_metric>::compute_status(
         double val = _data_index >= nb_metric
                          ? values.second.get_proportional_used()
                          : values.second.get_proportional_value(_data_index);
-        if (_threshold.is_triggered(val)) {
+        if (val > _threshold) {
           auto& to_update = (*per_cpu_status)[values.first];
           // if ok (=0) and _status is warning (=1) or critical(=2), we update
           if (_status > to_update) {
@@ -211,11 +210,7 @@ void cpu_to_status<nb_metric>::compute_status(
  * @param io_context
  * @param logger
  * @param first_start_expected start expected
- * @param check_interval check interval between two checks (not only this but
- * also others)
  * @param serv service
- * @param cmd_name
- * @param cmd_line
  * @param args native plugin arguments
  * @param cnf engine configuration received object
  * @param handler called at measure completion
@@ -225,10 +220,7 @@ native_check_cpu<nb_metric>::native_check_cpu(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const rapidjson::Value& args,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
@@ -236,10 +228,7 @@ native_check_cpu<nb_metric>::native_check_cpu(
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
             stat),
@@ -409,15 +398,15 @@ e_status native_check_cpu<nb_metric>::_compute(
     auto cpu_to_status_search = _cpu_to_status.find(
         std::make_tuple(index, is_average, e_status::warning));
     if (cpu_to_status_search != _cpu_to_status.end()) {
-      cpu_to_status_search->second.get_threshold().set_pref_details_w(to_add,
-                                                                      100.0);
+      to_add.warning_low(0);
+      to_add.warning(100 * cpu_to_status_search->second.get_threshold());
     }
     // critical
     cpu_to_status_search = _cpu_to_status.find(
         std::make_tuple(index, is_average, e_status::critical));
     if (cpu_to_status_search != _cpu_to_status.end()) {
-      cpu_to_status_search->second.get_threshold().set_pref_details_c(to_add,
-                                                                      100.0);
+      to_add.critical_low(0);
+      to_add.critical(100 * cpu_to_status_search->second.get_threshold());
     }
     perfs->emplace_back(std::move(to_add));
   };
