@@ -35,16 +35,14 @@ class test_check : public check_memory {
  public:
   static MEMORYSTATUSEX mock;
   static PERFORMANCE_INFORMATION perf_mock;
+  static Service serv;
 
   test_check(const rapidjson::Value& args)
       : check_memory(
             g_io_context,
             spdlog::default_logger(),
             {},
-            {},
-            "serv"s,
-            "cmd_name"s,
-            "cmd_line"s,
+            serv,
             args,
             nullptr,
             [](const std::shared_ptr<check>& caller,
@@ -88,6 +86,8 @@ PERFORMANCE_INFORMATION test_check::perf_mock = {
     0,                 // ThreadCount
 };
 
+Service test_check::serv;
+
 const uint64_t _total_phys = test_check::mock.ullTotalPhys;
 const uint64_t _available_phys = test_check::mock.ullAvailPhys;
 const uint64_t _total_swap =
@@ -203,7 +203,7 @@ TEST(native_check_memory_windows, output_no_threshold3) {
 TEST(native_check_memory_windows, output_threshold) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
-      R"({ "warning-usage-free": "8388609:", "critical-usage-prct": 99.99, "warning-virtual": "20000000000", "critical-virtual": 50000000000 })"_json;
+      R"({ "warning-usage-free": "8388609", "critical-usage-prct": 99.99, "warning-virtual": "20000000000", "critical-virtual": 50000000000 })"_json;
   test_check to_check(check_args);
   std::string output;
   std::list<com::centreon::common::perfdata> perfs;
@@ -218,8 +218,8 @@ TEST(native_check_memory_windows, output_threshold) {
   test_perfs(perfs);
   for (const auto& perf : perfs) {
     if (perf.name() == "memory.free.bytes") {
-      ASSERT_TRUE(std::isnan(perf.warning()));
-      ASSERT_EQ(perf.warning_low(), 8388609);
+      ASSERT_EQ(perf.warning_low(), 0);
+      ASSERT_EQ(perf.warning(), 8388609);
     } else if (perf.name() == "memory.usage.percentage") {
       ASSERT_EQ(perf.critical_low(), 0);
       ASSERT_NEAR(perf.critical(), 99.99, 0.01);
