@@ -36,6 +36,7 @@ tasksched_data g_data1, g_data2, g_data3;
 
 class check_windows_sched : public ::testing::Test {
  public:
+  Service serv;
   static void SetUpTestCase() {
     auto make_date_info = [](std::chrono::system_clock::time_point when) {
       std::time_t t = std::chrono::system_clock::to_time_t(when);
@@ -96,8 +97,8 @@ class check_windows_sched : public ::testing::Test {
  * filter-tasks : "enabled == 1"
  * warning-status : "exit_code != 0x0"
  * critical-status : "exit_code < 0x0"
- * warning_count : 1
- * critical_count : 1
+ * warning-count : 1
+ * critical-count : 1
  * verbose : false
  */
 TEST_F(check_windows_sched, default_check_sched) {
@@ -105,8 +106,7 @@ TEST_F(check_windows_sched, default_check_sched) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -259,8 +259,7 @@ TEST_F(check_windows_sched, filter_task1) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -290,8 +289,7 @@ TEST_F(check_windows_sched, filter_task2) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -321,8 +319,7 @@ TEST_F(check_windows_sched, filter_task3) {
   })t"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -353,8 +350,7 @@ TEST_F(check_windows_sched, warning_filter) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -388,8 +384,7 @@ TEST_F(check_windows_sched, exclude_tasks) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -427,8 +422,7 @@ TEST_F(check_windows_sched, output_format) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -458,8 +452,7 @@ TEST_F(check_windows_sched, output_format_2) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -490,8 +483,7 @@ TEST_F(check_windows_sched, filter_by_name_and_author) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -529,8 +521,7 @@ TEST_F(check_windows_sched, filter_by_last_run) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
@@ -564,8 +555,7 @@ TEST_F(check_windows_sched, warning_last_run) {
   })"_json;
 
   check_sched checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, json_config, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, json_config, nullptr,
       [](const std::shared_ptr<check>&, int,
          const std::list<com::centreon::common::perfdata>&,
          const std::list<std::string>&) {},
