@@ -18,10 +18,6 @@
 
 #include <absl/synchronization/mutex.h>
 #include <gtest/gtest.h>
-#include <chrono>
-#include <cstdint>
-#include <memory>
-#include <mutex>
 
 #include "com/centreon/common/rapidjson_helper.hh"
 
@@ -81,6 +77,14 @@ std::array<sample, 9> _samples = {
 
 class drive_size_test : public ::testing::Test {
  public:
+  Service serv;
+
+  drive_size_test() {
+    serv.set_service_description("serv");
+    serv.set_command_name("cmd_name");
+    serv.set_command_line("cmd_line");
+  }
+
   static std::list<fs_stat> compute(
       filter& filt,
       const std::shared_ptr<spdlog::logger>& logger);
@@ -120,8 +124,7 @@ TEST_F(drive_size_test, test_fs_filter1) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -188,8 +191,7 @@ TEST_F(drive_size_test, test_fs_filter_percent) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -256,8 +258,7 @@ TEST_F(drive_size_test, test_fs_filter2) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -312,8 +313,7 @@ TEST_F(drive_size_test, test_fs_filter_percent_2) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -377,8 +377,7 @@ TEST_F(drive_size_test, test_fs_filter_percent_3) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -436,8 +435,7 @@ TEST_F(drive_size_test, test_fs_filter_percent_4) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -502,8 +500,7 @@ TEST_F(drive_size_test, test_fs_filter_percent_5) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -563,8 +560,7 @@ TEST_F(drive_size_test, test_fs_filter_percent_6) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -611,7 +607,7 @@ TEST_F(drive_size_test, test_fs_filter_percent_6) {
 TEST_F(drive_size_test, test_fs_filter_free_percent) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
-      R"({ "warning" : "70:", "critical" : "50:", "unit": "%", "free": true,
+      R"({ "warning" : "70", "critical" : "50", "unit": "%", "free": true,
          "exclude-fs": "tmpfs", "exclude-mountpoint":"/dev" })"_json;
 
   absl::Mutex wait_m;
@@ -624,8 +620,7 @@ TEST_F(drive_size_test, test_fs_filter_free_percent) {
 
   auto checker = std::make_shared<check_drive_size>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -650,10 +645,10 @@ TEST_F(drive_size_test, test_fs_filter_free_percent) {
   for (const auto& p : perfs) {
     ASSERT_EQ(p.unit(), "%");
     ASSERT_EQ(p.min(), 0);
-    ASSERT_EQ(p.warning_low(), 70);
-    ASSERT_EQ(p.critical_low(), 50);
-    ASSERT_TRUE(std::isnan(p.warning()));
-    ASSERT_TRUE(std::isnan(p.critical()));
+    ASSERT_EQ(p.warning_low(), 0);
+    ASSERT_EQ(p.critical_low(), 0);
+    ASSERT_EQ(p.warning(), 70);
+    ASSERT_EQ(p.critical(), 50);
     if (p.name() == "free_/") {
       ASSERT_NEAR(p.value(), 60.46, 0.01);
       ASSERT_EQ(p.max(), 100);
