@@ -30,7 +30,7 @@ class ApplierBoolexp : public ::testing::Test {
  public:
   void SetUp() override {
     // Initialization.
-    config::applier::init(0, "test_broker", 0);
+    config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
     auto logger = log_v2::instance().get(log_v2::BAM);
 
     _aply_state = std::make_unique<bam::configuration::applier::state>(logger);
