@@ -26,7 +26,7 @@ using namespace com::centreon::broker;
 class PublisherRead : public testing::Test {
  public:
   void SetUp() override {
-    config::applier::init(0, "test_broker", 0);
+    config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
   }
 
   void TearDown() override { config::applier::deinit(); }
