@@ -16,7 +16,6 @@
  * For more information : contact@centreon.com
  */
 #include "com/centreon/broker/io/endpoint.hh"
-#include "com/centreon/common/pool.hh"
 
 #include "com/centreon/broker/persistent_cache.hh"
 
@@ -36,8 +35,7 @@ endpoint::endpoint(bool is_accptr,
                    const multiplexing::muxer_filter& forbidden_filter)
     : _is_acceptor(is_accptr),
       _stream_mandatory_filter{mandatory_filter},
-      _stream_forbidden_filter{forbidden_filter},
-      _io_context(com::centreon::common::pool::io_context_ptr()) {}
+      _stream_forbidden_filter{forbidden_filter} {}
 
 /**
  *  Copy constructor.
@@ -48,8 +46,7 @@ endpoint::endpoint(endpoint const& other)
     : _is_acceptor(other._is_acceptor),
       _stream_mandatory_filter{other._stream_mandatory_filter},
       _stream_forbidden_filter{other._stream_forbidden_filter},
-      _from(other._from),
-      _io_context(other._io_context) {}
+      _from(other._from) {}
 
 /**
  *  Set the lower layer endpoint object of this endpoint.
