@@ -18,11 +18,9 @@
 
 #include "com/centreon/broker/persistent_file.hh"
 
-#include "com/centreon/broker/bbdo/stream.hh"
+#include "broker/core/bbdo/stream.hh"
 #include "com/centreon/broker/compression/stream.hh"
-#include "com/centreon/broker/file/opener.hh"
-#include "com/centreon/broker/file/stream.hh"
-#include "com/centreon/broker/stats/center.hh"
+#include "com/centreon/broker/config/applier/state.hh"
 #include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::broker;
@@ -54,7 +52,7 @@ persistent_file::persistent_file(const std::string& path, QueueFileStats* stats)
   // Set stream.
   io::stream::set_substream(bs);
   if (stats)
-    stats::center::instance_ptr()->execute(
+    config::applier::state::instance().center()->execute(
         [path, stats, max_file_size = _splitter->max_file_size()] {
           stats->set_name(path);
           stats->set_max_file_size(max_file_size);
