@@ -30,7 +30,7 @@ class CompressionStreamRead : public ::testing::Test {
  public:
   void SetUp() override {
     try {
-      config::applier::init(0, "test_broker", 0);
+      config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
     } catch (const std::exception& e) {
       (void)e;
     }
