@@ -102,7 +102,7 @@ int main(int argc, char* argv[]) {
   QCoreApplication app(argc, argv);
 
   // Initialization.
-  config::applier::init(0, "test_broker", 0);
+  config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
 
   // Generate file name.
   QString filename(QDir::tempPath());
