@@ -52,9 +52,7 @@ class server_stream : public client_stream_base_class {
 
  public:
   server_stream(const grpc_config::pointer& conf,
-                const std::shared_ptr<service_impl>& serv,
-                const std::shared_ptr<asio::io_context> io_context,
-                const std::shared_ptr<spdlog::logger>& logger);
+                const std::shared_ptr<service_impl>& serv);
 
   void OnDone() override;
 };
@@ -65,11 +63,8 @@ class server_stream : public client_stream_base_class {
  * @param conf
  */
 server_stream::server_stream(const grpc_config::pointer& conf,
-                             const std::shared_ptr<service_impl>& serv,
-                             const std::shared_ptr<asio::io_context> io_context,
-                             const std::shared_ptr<spdlog::logger>& logger)
-    : client_stream_base_class(conf, "accepted", io_context, logger),
-      _parent(serv) {}
+                             const std::shared_ptr<service_impl>& serv)
+    : client_stream_base_class(conf, "accepted"), _parent(serv) {}
 
 /**
  * @brief shutdown bireactor
@@ -99,10 +94,7 @@ void server_stream::OnDone() {
  *
  * @param conf
  */
-service_impl::service_impl(const grpc_config::pointer& conf,
-                           const std::shared_ptr<asio::io_context> io_context,
-                           const std::shared_ptr<spdlog::logger>& logger)
-    : _conf(conf), _logger(logger), _io_context(io_context) {}
+service_impl::service_impl(const grpc_config::pointer& conf) : _conf(conf) {}
 
 /**
  * @brief to call after construction
@@ -130,19 +122,20 @@ void service_impl::init() {
 ::grpc::ServerBidiReactor<::com::centreon::broker::stream::CentreonEvent,
                           ::com::centreon::broker::stream::CentreonEvent>*
 service_impl::exchange(::grpc::CallbackServerContext* context) {
+  auto logger = log_v2::instance().get(log_v2::GRPC);
   if (!_conf->get_authorization().empty()) {
     const auto& metas = context->client_metadata();
 
     auto header_search = metas.lower_bound(authorization_header);
     if (header_search == metas.end()) {
-      SPDLOG_LOGGER_ERROR(_logger, "header {} not found from {}",
+      SPDLOG_LOGGER_ERROR(logger, "header {} not found from {}",
                           authorization_header, context->peer());
       return nullptr;
     }
     bool found = false;
     for (; header_search != metas.end() && !found; ++header_search) {
       if (header_search->first != authorization_header) {
-        SPDLOG_LOGGER_ERROR(_logger, "Wrong client authorization token from {}",
+        SPDLOG_LOGGER_ERROR(logger, "Wrong client authorization token from {}",
                             context->peer());
         return nullptr;
       }
@@ -150,10 +143,10 @@ service_impl::exchange(::grpc::CallbackServerContext* context) {
     }
   }
 
-  SPDLOG_LOGGER_DEBUG(_logger, "connection accepted from {}", context->peer());
+  SPDLOG_LOGGER_DEBUG(logger, "connection accepted from {}", context->peer());
 
-  std::shared_ptr<server_stream> next_stream = std::make_shared<server_stream>(
-      _conf, shared_from_this(), _io_context, _logger);
+  std::shared_ptr<server_stream> next_stream =
+      std::make_shared<server_stream>(_conf, shared_from_this());
 
   server_stream::register_stream(next_stream);
   next_stream->start_read();
@@ -270,8 +263,7 @@ acceptor::acceptor(const grpc_config::pointer& conf)
           log_v2::instance().get(log_v2::GRPC)) {
   _init([this](::grpc::ServerBuilder& builder) {
     _service = std::make_shared<service_impl>(
-        std::static_pointer_cast<grpc_config>(get_conf()), get_io_context(),
-        get_logger());
+        std::static_pointer_cast<grpc_config>(get_conf()));
     _service->init();
     builder.RegisterService(_service.get());
   });
