@@ -21,16 +21,13 @@
 #include <gtest/gtest.h>
 
 #include "bbdo/storage/status.hh"
-#include "com/centreon/broker/bbdo/stream.hh"
+#include "broker/core/bbdo/stream.hh"
 #include "com/centreon/broker/config/applier/init.hh"
-#include "com/centreon/broker/io/events.hh"
 #include "com/centreon/broker/io/protocols.hh"
-#include "com/centreon/broker/io/raw.hh"
 #include "com/centreon/broker/lua/macro_cache.hh"
 #include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/broker/misc/variant.hh"
 #include "com/centreon/broker/modules/handle.hh"
-#include "com/centreon/broker/neb/instance.hh"
 #include "com/centreon/broker/unified_sql/factory.hh"
 #include "common/log_v2/log_v2.hh"
 
@@ -72,7 +69,7 @@ class UnifiedSqlEntryTest : public ::testing::Test {
   void SetUp() override {
     io::data::broker_id = 0;
     try {
-      config::applier::init(0, "test_broker", 0);
+      config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
     } catch (std::exception const& e) {
       (void)e;
     }
