@@ -19,12 +19,11 @@
  */
 
 #include "com/centreon/engine/broker/loader.hh"
+#include <filesystem>
 #include "com/centreon/engine/broker/handle.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/logging/logger.hh"
-#include "com/centreon/io/directory_entry.hh"
-#include "com/centreon/io/file_stream.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
@@ -41,8 +40,16 @@ using namespace com::centreon::engine::logging;
  *  @return The new object module.
  */
 std::shared_ptr<engine::broker::handle> loader::add_module(
-    std::string const& filename,
-    std::string const& args) {
+    const std::string& filename,
+    const std::string& args) {
+  // Little hook to stop to load this old module.
+  if (filename.find("cbmod.so") != std::string::npos) {
+    config_logger->error(
+        "Broker module '{}' is deprecated and will be removed in future "
+        "versions. Please remove this module from your configuration.",
+        filename);
+    return nullptr;
+  }
   auto module = std::make_shared<handle>(filename, args);
   _modules.push_back(module);
   return module;
@@ -92,43 +99,42 @@ loader& loader::instance() {
  */
 unsigned int loader::load_directory(std::string const& dir) {
   // Get directory entries.
-  io::directory_entry directory(dir);
-  std::list<io::file_entry> const& files(directory.entry_list("*.so"));
+
+  std::filesystem::path directory(dir);
+  std::list<std::filesystem::path> files;
+  for (const auto& entry : std::filesystem::directory_iterator(directory)) {
+    if (entry.is_regular_file() && entry.path().extension() == ".so") {
+      files.push_back(entry.path());
+    }
+  }
 
   // Sort by file name.
-  std::multimap<std::string, io::file_entry> sort_files;
-  for (std::list<io::file_entry>::const_iterator it(files.begin()),
-       end(files.end());
-       it != end; ++it)
-    sort_files.insert(std::make_pair(it->file_name(), *it));
+  std::multimap<std::string, std::filesystem::path> sort_files;
+  for (const auto& file : files)
+    sort_files.insert(std::make_pair(file.filename().string(), file));
 
   // Load modules.
-  unsigned int loaded(0);
-  for (std::multimap<std::string, io::file_entry>::const_iterator
-           it(sort_files.begin()),
-       end(sort_files.end());
-       it != end; ++it) {
-    io::file_entry const& f(it->second);
-    std::string config_file(dir + "/" + f.base_name() + ".cfg");
-    if (io::file_stream::exists(config_file.c_str()) == false)
-      config_file = "";
+  unsigned int loaded = 0;
+  for (const auto& [name, f] : sort_files) {
+    std::string cfg_file = f.stem().string() + ".cfg";
+    std::filesystem::path config_file = dir / std::filesystem::path(cfg_file);
+    if (!std::filesystem::exists(config_file))
+      config_file.clear();
+
     std::shared_ptr<handle> module;
     try {
-      module = add_module(dir + "/" + f.file_name(), config_file);
-      module->open();
-      engine_logger(log_info_message, basic)
-          << "Event broker module '" << f.file_name()
-          << "' initialized successfully.";
-      events_logger->info("Event broker module '{}' initialized successfully.",
-                          f.file_name());
-      ++loaded;
+      module = add_module(dir / f, config_file);
+      if (module) {
+        module->open();
+        events_logger->info(
+            "Event broker module '{}' initialized successfully.",
+            f.filename().string());
+        ++loaded;
+      }
     } catch (error const& e) {
       del_module(module);
-      engine_logger(log_runtime_error, basic)
-          << "Error: Could not load module '" << f.file_name() << "' -> "
-          << e.what();
       runtime_logger->error("Error: Could not load module '{}' -> {}",
-                            f.file_name(), e.what());
+                            f.filename().string(), e.what());
     }
   }
   return loaded;
