@@ -326,6 +326,8 @@ void applier::anomalydetection::modify_object(
     }
   }
 
+  // update the global anomalydetection configuration
+  old_obj->CopyFrom(new_obj);
   // Notify event broker.
   broker_adaptive_service_data(NEBTYPE_SERVICE_UPDATE, NEBFLAG_NONE, s.get(),
                                MODATTR_ALL);
