@@ -19,6 +19,7 @@
 
 #include "helper.hh"
 
+#include "cbmod_test.hh"
 #include "com/centreon/engine/checks/checker.hh"
 #include "com/centreon/engine/configuration/applier/logging.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
@@ -31,35 +32,13 @@ using namespace com::centreon::engine;
 using com::centreon::common::log_v2::log_v2;
 using log_v2_config = com::centreon::common::log_v2::config;
 
-#ifdef LEGACY_CONF
-extern configuration::state* config;
-#else
 extern configuration::State pb_config;
-#endif
 
-#ifdef LEGACY_CONF
-void init_config_state() {
-  if (config == nullptr)
-    config = new configuration::state;
-
-  config->log_file_line(true);
-  config->log_file("");
-
-  log_v2_config log_conf(
-      "engine-tests", log_v2_config::logger_type::LOGGER_STDOUT,
-      config->log_flush_period(), config->log_pid(), config->log_file_line());
-
-  log_v2::instance().apply(log_conf);
-
-  // Hack to instanciate the logger.
-  configuration::applier::logging::instance().apply(*config);
-
-  checks::checker::init(true);
-}
-#else
 void init_config_state() {
   /* Cleanup */
   pb_config.Clear();
+  if (!cbm)
+    cbm = std::make_unique<com::centreon::broker::neb::cbmod_test>();
 
   configuration::state_helper cfg_hlp(&pb_config);
   pb_config.set_log_file_line(true);
@@ -70,6 +49,10 @@ void init_config_state() {
                          pb_config.log_flush_period(), pb_config.log_pid(),
                          pb_config.log_file_line());
 
+  log_conf.set_level("checks", "debug");
+  log_conf.set_level("events", "trace");
+  log_conf.set_level("notifications", "trace");
+
   log_v2::instance().apply(log_conf);
 
   // Hack to instanciate the logger.
@@ -77,15 +60,9 @@ void init_config_state() {
 
   checks::checker::init(true);
 }
-#endif
 
 void deinit_config_state(void) {
-#ifdef LEGACY_CONF
-  delete config;
-  config = nullptr;
-#else
   pb_config.Clear();
-#endif
 
   configuration::applier::state::instance().clear();
   checks::checker::deinit();
